OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s е публикувал календар »%s«",
    "Successfully sent email to " : "Успешно изпратен имейл до",
    "Hello," : "Здравейте, ",
    "We wanted to inform you that %s has published the calendar »%s«." : "Информираме ви, че%s е публикувал календара »%s«.",
    "Open »%s«" : "Отвори »%s«",
    "Cheers!" : "Поздрави!",
    "Calendar" : "Календар",
    "A Calendar app for Nextcloud" : "Календар за Nextcloud",
    "Previous day" : "Вчера",
    "Previous week" : "Миналата седмица",
    "Previous month" : "Предишен месец",
    "Next day" : "Утре",
    "Next week" : "Следваща седмица",
    "Next month" : "Следващия месец",
    "+ New event" : "Ново събитие",
    "Today" : "Днес",
    "Day" : "Ден",
    "Week" : "Седмица",
    "Month" : "Месец",
    "Untitled calendar" : "Нов календар",
    "Edit name" : "Редактирай името",
    "Saving name …" : "Запазване...",
    "Edit color" : "Смени цвета",
    "Saving color …" : "Запазване на цвета ...",
    "Copy private link" : "Копирай скритата връзка",
    "Download" : "Изтегляне",
    "Delete" : "Изтриване",
    "Calendar link copied to clipboard." : "Копирано в клипборда",
    "Share link" : "Връзка за споделяне",
    "Publish calendar" : "Публикувай календара",
    "Publishing calendar" : "Публикуване на календара",
    "Copy public link" : "Копирай публичната връзка",
    "Send link to calendar via email" : "Изпрати връзката по имейл",
    "Copied link" : "Копирано!",
    "Delete share link" : "Изтрий споделената връзка",
    "Share with users or groups" : "Сподели с потребители или групи",
    "can edit" : "може да редактира",
    "+ New calendar" : "Нов календар",
    "New calendar" : "Нов календар",
    "Import calendars" : "Импортиране на календари",
    "Filename" : "Име на файла",
    "Calendar to import into" : "Избран календар за внасяне в",
    "Cancel" : "Отказ",
    "_Import calendar_::_Import calendars_" : ["Импортиране на календар","Импортиране на календари"],
    "Automatic" : "Автоматично",
    "Show weekends" : "Покажи събота и неделя",
    "Show week numbers" : "Показвай номерата на седмиците",
    "Settings & import" : "Настройки и внасяне",
    "Notification" : "Известие",
    "Email" : "Имейл",
    "On date" : "На дата",
    "Edit time" : "Редакирай времето",
    "Remove reminder" : "Премахни напомнянето",
    "+ Add reminder" : "+ Добави напомняне",
    "_second_::_seconds_" : ["секунда","секунди"],
    "_minute_::_minutes_" : ["минута","минути"],
    "_hour_::_hours_" : ["час","часове"],
    "_day_::_days_" : ["ден","дни"],
    "_week_::_weeks_" : ["седмица","седмици"],
    "No reminders yet" : "Няма напомняния",
    "Busy" : "Зает",
    "Unknown" : "Непознат",
    "Send e-mail" : "Изпрати имейл",
    "All day" : "Цял ден",
    "never" : "никога",
    "after" : "след",
    "first" : "първи",
    "third" : "трети",
    "fourth" : "четвърти",
    "fifth" : "пети",
    "last" : "последен",
    "Repeat" : "Да се повтаря",
    "Repeat every" : "Повтаряй всеки",
    "On the" : "На",
    "_month_::_months_" : ["месец","месеци"],
    "_year_::_years_" : ["година","години"],
    "Monday" : "понеделник",
    "Summary" : "Резюме",
    "More" : "Още",
    "Save" : "Запазване",
    "Update" : "Обновяване",
    "Select Date" : "Изберете дата",
    "Personal" : "Лични",
    "Details" : "Подробности",
    "Attendees" : "Участници",
    "Reminders" : "Напомняне",
    "Activity" : "Активност",
    "Close" : "Затвори",
    "Anniversary" : "Годишнина",
    "Week {number} of {year}" : "Седмица {number} от {year}",
    "Does not repeat" : "Не се повтаря",
    "Daily" : "Всеки ден",
    "Weekly" : "Всяка седмица",
    "Monthly" : "Месечно",
    "Yearly" : "Годишно",
    "_Every %n day_::_Every %n days_" : ["Всеки %n ден","Всеки %n дни"],
    "When shared show full event" : "При споделяне, показвай цялото събитие",
    "When shared show only busy" : "При споделяне, показвай само статус \"зает\"",
    "When shared hide this event" : "При споделяне, скривай това събитие",
    "Location" : "Местоположение",
    "Description" : "Описание",
    "Add a description" : "Добави описание",
    "Status" : "Състояние",
    "Confirmed" : "Потвърдено",
    "Tentative" : "Несигурно",
    "Cancelled" : "Отказано",
    "Categories" : "Категории",
    "Add this as a new category" : "Добави като нова категория",
    "Presentation" : "Презентация",
    "Cinema" : "Кино",
    "Mail" : "Поща",
    "Play" : "Пусни",
    "Dentist" : "Зъболекар",
    "Global" : "Глобални"
},
"nplurals=2; plural=(n != 1);");
